/* This is needed for the event fifo */
#define EXEC_EVENT_FIFO_SIZE 8
#define EXEC_EVENT_FIFO_MASK EXEC_EVENT_FIFO_SIZE-1 
#include "EventCodes.h"

/* This bitmask holds events that need to be processed as fast as possible */
unsigned char FastEventBitmask = 0x00;
unsigned char EventsList[EXEC_EVENT_FIFO_SIZE];
unsigned char EventHead=0;
unsigned char EventTail=0;

#define PUBLISH_EVENT(event) PlaceEvent(event)
#define PUBLISH_FAST_EVENT(event) FastEventBitmask |= event

/***********************************************************
  Function Name: Exec_readEventFifo
  Function Description: This function is responsible for
  reading a single event out of the event fifo.
  Inputs:  none
  Outputs: unsigned char-the data read
***********************************************************/
unsigned char GetEvent(void)
{
  unsigned char Event = EV_NO_EVENT;
  unsigned char StatusReg = StatusRegister;
  DisableInterrupts();
  /* just return the current tail from the tx fifo */
  if (EventTail != EventHead)
  {
    Event = EventsList[EventTail++];
    EventTail &= EXEC_EVENT_FIFO_MASK;
  }
  StatusRegister = StatusReg;
  return Event;
}

/***********************************************************
  Function Name: Exec_writeEventFifo
  Function Description: This function is responsible for
  writing a single event to the event fifo and
  updating the appropriate pointers.
  Inputs:  data - the byte to write to the Fifo
  Outputs: none
***********************************************************/
void PlaceEvent(unsigned char Event)
{
  unsigned char StatusReg = StatusRegister;
  DisableInterrupts();
  EventsList[EventHead++] = Event;
  EventHead &= EXEC_EVENT_FIFO_MASK;
  StatusRegister = StatusReg;
}
