/*
    Copyright (C) 2004    John Orlando

   AVRcam: a small real-time image processing engine.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public
    License along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   For more information on the AVRcam, please contact:

   john@jrobot.net

   or go to www.jrobot.net for more details regarding the system.
*/
/***********************************************************
	Module Name: Utility.c
	Module Date: 04/13/2004
	Module Auth: John Orlando

	Description: This module provides a basic set of
	general purpose utilities that can be used by any
	module needing them.

    Revision History:
    Date        Rel Ver.    Notes
    4/10/2004      0.1     Module created
    6/30/2004      1.0     Initial release for Circuit Cellar
                           contest.
***********************************************************/

/*	Includes */

/*  Local Variables */

/* 	Local Structures and Typedefs */

/*  Extern Variables */

/*  Definitions */
#define TRUE  1
#define FALSE 0

#define BIT0 0
#define BIT1 1
#define BIT2 2 
#define BIT3 3
#define BIT4 4
#define BIT5 5
#define BIT6 6
#define BIT7 7

#define COMPLETE_COLOR_MAP 1
//#define DEBUG_TRACKED_LINE 1
//#define DEBUG_COLOR_MAP 1
/***********************************************************
	Function Name: Utility_delay
	Function Description: This function provides a busy-wait
	delay for a specified number of milliseconds.
	Inputs:  numMs - the number of milliseconds to delay
	Outputs: none
	NOTES: The delay_loop_1 and delay_loop_2 functions found
	in avr/delay.h provide accurate 3 and 4 cycle delay loops
	if needed...this isn't really a millisecond, so DON'T
    depend on it for exact timing...
***********************************************************/
void Utility_delay(unsigned short numMs)
{
	volatile unsigned short i=0,j=0;
#ifndef SIMULATION
	for (i=0; i<numMs; i++)
	{
		for (j=0; j<1000; j++)
		{
			Nop();
		}
	}
#endif
}

unsigned char HexSymbol(unsigned char Value)
{
  if (Value<10)
    return '0'+Value;
  else
    return 'A'-10+Value;
}

unsigned char HexDigit(unsigned char Symbol)
{
    if (Symbol < 'A')
        return Symbol-'0';
    else
        return Symbol-'A'+10;
}


unsigned char HexValue(unsigned char *Buffer, unsigned char Offset)
{
    return (HexDigit(*(Buffer+Offset)<<4)|HexDigit(*(Buffer+Offset+1)));
}

void HexByte(unsigned char Value, unsigned char *Buffer)
{
  *Buffer++=HexSymbol(Value>>4);
  *Buffer++=HexSymbol(Value&0x0F);
  *Buffer=0x00; //      itoa();       
}

unsigned char DecSymbol(unsigned char Value)
{
  return '0'+Value;
}

unsigned char DecDigit(unsigned char Symbol)
{
  return Symbol-'0';
}

//            , . .  '0';  '2';'5';'5';
unsigned char DecValue(unsigned char *Buffer, unsigned char Offset)
{
  if((*(Buffer+Offset+1)) == 0x00)
    return DecDigit(*(Buffer+Offset));
  else if ((*(Buffer+Offset+2) == 0x00))
    return ((DecDigit(*(Buffer+Offset))*10)+DecDigit(*(Buffer+Offset+1)));
  else
    return ((DecDigit(*(Buffer+Offset))*100)+(DecDigit(*(Buffer+Offset+1))*10)+(DecDigit(*(Buffer+Offset+2))));
}

void DecByte(unsigned char Value, unsigned char *Buffer)
{
  unsigned char Hundred, Teen, Uno;
  Hundred = Value/100;    //   
  Teen = (Value%100)/10;  //     ,       
  Uno = (Value%100)%10;   //     ,   .   
  //if (Hundred)
    *Buffer++=DecSymbol(Hundred);
  //if (Teen)
    *Buffer++=DecSymbol(Teen);
  *Buffer=DecSymbol(Uno);
}

void MemSet(unsigned char *Buffer, unsigned char Value, unsigned char Size)
{
  while (Size--)
    *Buffer++=Value;
}

