/*
    Copyright (C) 2004    John Orlando

   AVRcam: a small real-time image processing engine.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public
    License along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   For more information on the AVRcam, please contact:

   john@jrobot.net

   or go to www.jrobot.net for more details regarding the system.
*/
/***********************************************************
	Module Name: Main.c
	Module Date: 04/10/2004
	Module Auth: John Orlando

	Description:  This module is responsible for providing
	the entry point to the code through the "main" function.

    Revision History:
    Date        Rel Ver.    Notes
    4/10/2004      0.1     Module created
    6/30/2004      1.0     Initial release for Circuit Cellar
                           contest.
***********************************************************/

#define CPUFrequency    16000000
unsigned char CoMaHigh, CoMaLow;
/*	Includes */
#include "ATMega8.h"
#include "Events.h"
#include "Utility.h"
#include "DebugInterface.h"
#include "EEPROM.h"
#include "UART.h"
#include "I2CInterface.h"
#include "CamInterface.h"
#include "CamConfig.h"
#include "UIManager.h"
#include "FrameManager.h"
#include "Executive.h"

/* 	Local Structures and Typedefs */

/*  Extern Variables */

/*  Definitions */

/***********************************************************
	Function Name: main
	Function Description: This function provides the entry
	point into AVRcam application.
	Inputs:  none
	Outputs: int
***********************************************************/
int main(void)
{
  /* initialize all of the interface modules */
  DebugInterfaceInit();
  UartInit();
  I2CInit();
  CamInit();
  /* initialize the remaining modules that will process
  data...interrupts need to be on for these */
  EnableInterrupts();
  CamConfigInit();
  UIManagerInit();
  FrameManagerInit();
  BPortDData6 = 0;
  /* provide a short delay for the camera to stabilize before
  we let the executive start up */
  //Utility_delay(1000);
  BPortDData6 = 1;
  /* the rest of the application will be under the
  control of the Executive.  */
  ExecRun();

  /* this should never be reached */
  return(0);
}
